@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 import asyncio
+import json
 from typing import Any, List, Optional, Type, TypeVar
 
 from dotenv import load_dotenv
-from pydantic import Field
+from pydantic import BaseModel, Field
 from pydantic.main import ModelMetaclass
 
 from .client import FaunaClient
@@ -19,9 +20,11 @@ T = TypeVar("T", bound="FaunaModel")
 
 
 class FaunaModelMetaclass(ModelMetaclass):
-    def __new__(cls, name, bases, attrs):
-        new_cls = super().__new__(cls, name, bases, attrs)
-        cls.Metadata.__subclasses__.append(new_cls)
+    def __new__(mcs, name, bases, attrs):
+        new_cls = super().__new__(mcs, name, bases, attrs)
+        if bases and issubclass(bases[0], BaseModel):
+            new_cls.__doc__ = new_cls.schema_json()
+        mcs.Metadata.__subclasses__.append(new_cls)
         return new_cls
 
     class Metadata:
@@ -73,7 +76,7 @@ class FaunaModel(JSONModel, metaclass=FaunaModelMetaclass):
 
                 cls.logger.info("Created index %s", cls.__name__.lower())
 
-            for field in cls.__fields__.values():
+            for field in cls.model_fields.values():
                 if field.field_info.extra.get("unique"):
                     if not await _q(
                         q.exists(q.index(f"{cls.__name__.lower()}_{field.name}_unique"))
